# AIUTARE
Automated Analysis, Regression, and Evaluation

### Setup
- See the [Setup wiki page](https://github.com/FedericoAureliano/aiutare/wiki/Setup) for creating the config and other necessary files
```
bin/prepare.sh
```
- (Currently written only for Ubuntu 16.04 and 18.04)

### Usage
```
bin/run.py [absolute path to config.json file] [number of runs; 1 if omitted]
```